@@ -28,6 +28,9 @@
 #include <QtCore/QMap>
 #include <QtCore/QStringList>
 
+#define DEFAULT_PREFERRED_SEARCH_PROVIDERS \
+QStringList() << "google" << "youtube" << "yahoo" << "wikipedia" << "wikit"
+
 class SearchProvider;
 
 class KURISearchFilterEngine
@@ -35,11 +38,11 @@ class KURISearchFilterEngine
 public:
   typedef QMap <QString, QString> SubstMap;
 
-  KURISearchFilterEngine();
   ~KURISearchFilterEngine();
-  
+
   QByteArray name() const;
   char keywordDelimiter() const;
+  QString defaultSearchEngine() const;
   QStringList favoriteEngineList() const;
   SearchProvider* webShortcutQuery (const QString& typedString, QString& searchTerm) const;
   SearchProvider* autoWebSearchQuery (const QString& typedString, const QString& defaultEngine = QString()) const;
@@ -48,22 +51,25 @@ public:
 
   static KURISearchFilterEngine *self();
   void loadConfig();
-
+  
 protected:
   QString formatResult (const QString& url, const QString& cset1, const QString& cset2,
                         const QString& query, bool isMalformed, SubstMap& map) const;
 
 private:
-  QStringList modifySubstitutionMap (SubstMap& map, const QString& query) const;  
+  KURISearchFilterEngine();
+  KURISearchFilterEngine(const KURISearchFilterEngine&);
+  KURISearchFilterEngine& operator= (const KURISearchFilterEngine&);
   
-  QString substituteQuery (const QString& url, SubstMap &map, 
+  QStringList modifySubstitutionMap (SubstMap& map, const QString& query) const;
+  QString substituteQuery (const QString& url, SubstMap &map,
                            const QString& userquery, QTextCodec *codec) const;
-  
+
   QString m_defaultSearchEngine;
   QStringList m_favoriteEngines;
   bool m_bWebShortcutsEnabled;
+  bool m_bUseOnlySelectedShortcuts;
   char m_cKeywordDelimiter;
-  static KURISearchFilterEngine *s_pSelf;
 };
 
 #endif // KURIIKWSFILTERENG_H
