@@ -26,6 +26,9 @@
 /**
  * A simple wrapper around inotify which only allows
  * to add folders recursively.
+ *
+ * Warning: moving of top-level folders is not supported and
+ * results in undefined behaviour.
  */
 class KInotify : public QObject
 {
@@ -33,7 +36,7 @@ class KInotify : public QObject
 
 public:
     KInotify( QObject* parent = 0 );
-    ~KInotify();
+    virtual ~KInotify();
 
     /**
      * Inotify events that can occur. Use with addWatch
@@ -92,8 +95,15 @@ public:
 
     bool watchingPath( const QString& path ) const;
 
+protected:
+    /**
+     * Called for every folder that is being watched.
+     * Returns true if the watch should be add or false if it should NOT be added.
+     */
+    virtual bool filterWatch( const QString & path, WatchEvents & modes, WatchFlags & flags );
+
 public Q_SLOTS:
-    bool addWatch( const QString& path, WatchEvents modes, WatchFlags flags = WatchFlags() );
+    virtual bool addWatch( const QString& path, WatchEvents modes, WatchFlags flags = WatchFlags() );
     bool removeWatch( const QString& path );
 
 Q_SIGNALS:
@@ -127,7 +137,7 @@ Q_SIGNALS:
      * Emitted if a watched file or folder has been deleted.
      * This includes files in watched foldes (KInotify::EventDelete and KInotify::EventDeleteSelf)
      */
-    void deleted( const QString& file, bool isFolder );
+    void deleted( const QString& file, bool isDir );
 
     /**
      * Emitted if a watched file is modified (KInotify::EventModify)
