@@ -22,7 +22,7 @@
 #include <QtCore/QThread>
 #include <QtCore/QMutex>
 #include <QtCore/QWaitCondition>
-#include <QtCore/QSet>
+#include <QtCore/QQueue>
 #include <QtCore/QDateTime>
 
 #include <vector>
@@ -30,16 +30,13 @@
 
 #include <KUrl>
 
-namespace Strigi {
-    class StreamAnalyzer;
-    class IndexManager;
-}
-
 class QFileInfo;
 class QByteArray;
-class QTimer;
 
 namespace Nepomuk {
+
+    class Indexer;
+
     /**
      * The IndexScheduler performs the normal indexing,
      * ie. the initial indexing and the timed updates
@@ -52,7 +49,7 @@ namespace Nepomuk {
         Q_OBJECT
 
     public:
-        IndexScheduler( Strigi::IndexManager* manager, QObject* parent );
+        IndexScheduler( QObject* parent );
         ~IndexScheduler();
 
         bool isSuspended() const;
@@ -174,19 +171,26 @@ namespace Nepomuk {
     Q_SIGNALS:
         void indexingStarted();
         void indexingStopped();
+        /// a combination of the two signals above
+        void indexingStateChanged( bool indexing );
         void indexingFolder( const QString& );
         void indexingSuspended( bool suspended );
 
     private Q_SLOTS:
         void slotConfigChanged();
-        void slotDirsToUpdateWakeupTimeout();
 
     private:
         void run();
 
         bool waitForContinue( bool disableDelay = false );
-        bool updateDir( const QString& dir, Strigi::StreamAnalyzer* analyzer, UpdateDirFlags flags );
-        void analyzeFile( const QFileInfo& file, Strigi::StreamAnalyzer* analyzer );
+
+        /**
+         * It first indexes \p dir. Then it indexes all the files in \p dir, and
+         * finally recursivly analyzes all the subfolders in \p dir IF \p flags
+         * contains the 'UpdateRecursive' flag. It even sets m_currentFolder
+         */
+        bool analyzeDir( const QString& dir, UpdateDirFlags flags );
+
         void queueAllFoldersForUpdate( bool forceUpdate = false );
 
         /**
@@ -204,6 +208,7 @@ namespace Nepomuk {
          * to index anymore.
          */
         void removeOldAndUnwantedEntries();
+        bool removeAllGraphsFromQuery( const QString& query_ );
 
         bool m_suspended;
         bool m_stopped;
@@ -212,16 +217,21 @@ namespace Nepomuk {
         QMutex m_resumeStopMutex;
         QWaitCondition m_resumeStopWc;
 
-        class StoppableConfiguration;
-        StoppableConfiguration* m_analyzerConfig;
-        Strigi::IndexManager* m_indexManager;
+        Indexer* m_indexer;
 
-        // set of folders to update (+flags defined in the source file) - changed by updateDir
-        QSet<QPair<QString, UpdateDirFlags> > m_dirsToUpdate;
+        // A specialized queue that gives priority to dirs that do not use the AutoUpdateFolder flag.
+        class UpdateDirQueue : public QQueue<QPair<QString, UpdateDirFlags> >
+        {
+        public:
+            void enqueueDir( const QString& dir, UpdateDirFlags flags );
+            void prependDir( const QString& dir, UpdateDirFlags flags );
+            void clearByFlags( UpdateDirFlags mask );
+        };
+        // queue of folders to update (+flags defined in the source file) - changed by updateDir
+        UpdateDirQueue m_dirsToUpdate;
 
         QMutex m_dirsToUpdateMutex;
         QWaitCondition m_dirsToUpdateWc;
-        QTimer* m_dirsToUpdateWakeupTimer;
 
         QString m_currentFolder;
         KUrl m_currentUrl;
