@@ -563,7 +563,6 @@ void Nepomuk::StrigiIndexWriter::addTriplet( const std::string& s,
     if ( d->currentResultStack.top()->depth() > 0 ) {
         return;
     }
-
     //FileMetaData* md = fileDataForResult( d->currentResultStack.top() );
 
     Soprano::Node subject( createBlankOrResourceNode( s ) );
@@ -573,8 +572,13 @@ void Nepomuk::StrigiIndexWriter::addTriplet( const std::string& s,
         object = Soprano::Node( createBlankOrResourceNode( o ) );
     else
         object = Soprano::LiteralValue::fromString( QString::fromUtf8( o.c_str() ), property.literalRangeType().dataTypeUri() );
-
-    d->feeder->addStatement( subject, property.uri(), object );
+    
+    if( object.isValid() )
+        d->feeder->addStatement( subject, property.uri(), object );
+    else {
+        kDebug() << QString::fromUtf8( o.c_str() ) << " could not be parsed as a " << property.literalRangeType().dataTypeUri();
+    }
+        
 }
 
 
