@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2008-2010 Ralf Habacker <ralf.habacker@freenet.de>
+   Copyright (C) 2008-2011 Ralf Habacker <ralf.habacker@freenet.de>
    All rights reserved.
 
    This library is free software; you can redistribute it and/or
@@ -54,12 +54,14 @@ WinStartMenuModule::WinStartMenuModule(QObject* parent, const QList<QVariant>&)
     : KDEDModule(parent)
     , d( new WinStartMenuModulePrivate )
 {
+    // @todo merge with related stuff in main.cpp 
     KConfigGroup group( &d->config, "General" );
 
     if (group.readEntry("Enabled", true))
       connect(KSycoca::self(), SIGNAL(databaseChanged()), this, SLOT(databaseChanged()));
 
     globalOptions.useCategories = group.readEntry("useCategories", true);
+    globalOptions.rootCustomString = group.readEntry("rootCustomString", "");
     
     new WinStartMenuAdaptor( this );
 }
